@@ -1,6 +1,6 @@
 package Enbld::Command;
 
-use 5.012;
+use strict;
 use warnings;
 
 use Module::Load;
