@@ -1,6 +1,6 @@
 package Enbld::Definition::Apache;
 
-use 5.012;
+use strict;
 use warnings;
 
 use parent qw/Enbld::Definition/;
@@ -16,14 +16,11 @@ sub initialize {
     $self->{defined}{Extension}    = 'tar.gz';
     $self->{defined}{DownloadSite} = 'http://archive.apache.org/dist/httpd/';
 
-    $self->{defined}{Dependencies} = [ 'pcre', 'apr', 'aprutil' ];
+    $self->{defined}{Dependencies} = sub { return [ 'pcre', 'apr', 'aprutil' ] };
 
     $self->{defined}{AdditionalArgument}=   \&set_argument;
 
-    $self->{defined}{CommandConfigure}  =   './configure';
-    $self->{defined}{CommandMake}       =   'make';
-    $self->{defined}{CommandTest}       =   undef;
-    $self->{defined}{CommandInstall}    =   'make install';
+    $self->{defined}{CommandTest}       =   '';
 
     return $self;
 }
