@@ -3,7 +3,6 @@ package Enbld::Module;
 use strict;
 use warnings;
 
-use Module::Load;
 use Module::Load::Conditional qw/can_load/;
 
 require Enbld::Message;
@@ -15,26 +14,24 @@ sub new {
     my $self = {
         name            =>  undef,
         path            =>  undef,
-        command         =>  undef,
-        option          =>  undef,
+        module_file     =>  undef,
+        install_command =>  undef,
         @_,
     };
     
     my $module = 'Enbld::Module::' . ucfirst( $self->{name} );
-    if ( can_load( modules => { $module => undef } ) ) {
-        load $module;
+    can_load( modules => { $module => 0 } ) or
+        die( Enbld::Error->new( "no module for target '$self->{name}'" ));
 
-        bless $self, $module;
-        $self->initialize;
+    bless $self, $module;
 
-        return $self;
-    }
+    $self->initialize;
 
-    die( Enbld::Error->new( "no module for target '$self->{name}'" ));
+    return $self;
 }
 
 sub install {
-    my ( $self, $modules ) = @_;
+    my $self = shift;
 
     require Enbld::Logger;
     my $logfile = Enbld::Logger->logfile;
@@ -42,19 +39,14 @@ sub install {
     my $start_msg = "----> Start install modules for '$self->{name}'.";
     Enbld::Message->notify( $start_msg );
 
-    foreach my $name ( sort keys %{ $modules } ) {
+    my $cmd = $self->install_command;
 
-        my $module = $self->module( $name, $modules->{$name} );
-        my $cmd = $self->install_command( $module );
-
-        Enbld::Message->notify( "--> $cmd" );
-        system( "$cmd >> $logfile 2>&1" );
-
-        if ( $? >> 8 ) {
-            my $err = "Build fail.Command:$cmd return code:" . ( $? >> 8 );
-            die( Enbld::Error->new( $err ));
-        }
+    Enbld::Message->notify( "--> $cmd" );
+    system( "$cmd >> $logfile 2>&1" );
 
+    if ( $? >> 8 ) {
+        my $err = "Build fail.Command:$cmd return code:" . ( $? >> 8 );
+        die( Enbld::Error->new( $err ));
     }
 
     my $end_msg = "----> Finish install modules for '$self->{name}'.";
@@ -63,10 +55,6 @@ sub install {
     return $self;
 }
 
-sub module {
-    my ( $self, $name, $version ) = @_;
-}
-
 sub install_command {
     # virtual method
 }
